Learn R Programming

aws.signature (version 0.6.2)

assume_role_with_web_identity: Assume Role with AWS Web Identity

Description

Assume a role from a provided Web Identity Token and ARN using AWS Secure Token Service (STS).

Usage

assume_role_with_web_identity(
  role_arn,
  token_file,
  base_url = Sys.getenv("AWS_STS_ENDPOINT", "https://sts.amazonaws.com"),
  session_name = NULL,
  duration = 3600,
  version = "2011-06-15",
  verbose = getOption("verbose", FALSE)
)

Arguments

role_arn

A character string containing the AWS Role Amazon Resource Name (ARN). This specifies the permissions you have to access other AWS services.

token_file

A character string containing a path to a Web Identity Token file.

base_url

The AWS STS endpoint to use to retrieve your credentials from.

session_name

A character string optionally specifying the name.

duration

The expiry time on the retrieved credentials.

version

The AWS STS specification version to use.

verbose

A logical indicating whether to be verbose.