Assume a role from a provided Web Identity Token and ARN using AWS Secure Token Service (STS).
assume_role_with_web_identity(
role_arn,
token_file,
base_url = Sys.getenv("AWS_STS_ENDPOINT", "https://sts.amazonaws.com"),
session_name = NULL,
duration = 3600,
version = "2011-06-15",
verbose = getOption("verbose", FALSE)
)A character string containing the AWS Role Amazon Resource Name (ARN). This specifies the permissions you have to access other AWS services.
A character string containing a path to a Web Identity Token file.
The AWS STS endpoint to use to retrieve your credentials from.
A character string optionally specifying the name.
The expiry time on the retrieved credentials.
The AWS STS specification version to use.
A logical indicating whether to be verbose.